@@ -1,6 +1,7 @@
 """
 Mocks for the `class`
 """
+
 from ast import (
     AnnAssign,
     Assign,
@@ -36,13 +37,16 @@ from cdd.ast_utils import maybe_type_comment, set_arg, set_slice, set_value
 from cdd.defaults_utils import extract_default
 from cdd.pure_utils import tab
 from cdd.tests.mocks.docstrings import docstring_header_str
-from cdd.tests.mocks.methods import function_google_tf_squared_hinge_docstring_str
+from cdd.tests.mocks.methods import (
+    function_google_tf_squared_hinge_docstring_str,
+    returns_subscript,
+)
 from cdd.tests.utils_for_tests import remove_args_from_docstring
 
 class_doc_str = tab.join(
     (
         "\n",
-        "{header_doc_str}\n".format(header_doc_str=docstring_header_str),
+        "{header_doc_str}{tab}\n".format(header_doc_str=docstring_header_str, tab=tab),
         ':cvar dataset_name: name of dataset. Defaults to "mnist"\n',
         ':cvar tfds_dir: directory to look for models in. Defaults to "~/tensorflow_datasets"\n',
         ':cvar K: backend engine, e.g., `np` or `tf`. Defaults to "np"\n',
@@ -56,7 +60,7 @@ class_doc_str_expr = Expr(set_value(class_doc_str))
 class_str = '''
 class ConfigClass(object):
     """
-{header_doc_str}
+{header_doc_str}{tab}
     :cvar dataset_name: name of dataset. Defaults to "mnist"
     :cvar tfds_dir: directory to look for models in. Defaults to "~/tensorflow_datasets"
     :cvar K: backend engine, e.g., `np` or `tf`. Defaults to "np"
@@ -76,7 +80,7 @@ class ConfigClass(object):
         np.empty(0),
     )
 '''.format(
-    header_doc_str=indent(docstring_header_str, tab)
+    header_doc_str=indent(docstring_header_str, tab), tab=tab
 )
 
 class_nargs_str = '''
@@ -201,58 +205,7 @@ class_ast = ClassDef(
             expr_annotation=None,
         ),
         AnnAssign(
-            annotation=Subscript(
-                Name("Union", Load()),
-                Index(
-                    value=Tuple(
-                        ctx=Load(),
-                        elts=[
-                            Subscript(
-                                Name("Tuple", Load()),
-                                Index(
-                                    value=Tuple(
-                                        ctx=Load(),
-                                        elts=[
-                                            Attribute(
-                                                Attribute(
-                                                    Name("tf", Load()),
-                                                    "data",
-                                                    Load(),
-                                                ),
-                                                "Dataset",
-                                                Load(),
-                                            )
-                                        ]
-                                        * 2,
-                                        expr=None,
-                                    )
-                                ),
-                                Load(),
-                            ),
-                            Subscript(
-                                Name("Tuple", Load()),
-                                Index(
-                                    Tuple(
-                                        ctx=Load(),
-                                        elts=[
-                                            Attribute(
-                                                Name("np", Load()),
-                                                "ndarray",
-                                                Load(),
-                                            )
-                                        ]
-                                        * 2,
-                                        expr=None,
-                                    )
-                                ),
-                                Load(),
-                            ),
-                        ],
-                        expr=None,
-                    )
-                ),
-                Load(),
-            ),
+            annotation=returns_subscript,
             simple=1,
             target=Name("return_type", Store()),
             value=Tuple(
@@ -305,7 +258,7 @@ class_nargs_ast = ClassDef(
     body=[
         Expr(
             set_value(
-                "\n{tab}{header_doc_str}\n{tab}"
+                "\n{tab}{header_doc_str}{tab}\n{tab}"
                 ":cvar callbacks: Collection of callables that are run inside the training loop".format(
                     tab=tab, header_doc_str=docstring_header_str
                 ),
@@ -375,7 +328,7 @@ class_squared_hinge_config_ast = ClassDef(
     body=[
         Expr(
             set_value(
-                "\n{tab}{doc}\n{args}".format(
+                "\n{tab}{doc}{tab}\n{args}".format(
                     tab=tab,
                     # Inverse `emit_separating_tabs`
                     doc="\n".join(
@@ -400,9 +353,7 @@ class_squared_hinge_config_ast = ClassDef(
                                 " If binary (0 or 1) labels are provided we will convert them to -1 or 1."
                                 " shape = `[batch_size, d0, .. dN]`.",
                                 ":cvar y_pred: The predicted values. shape = `[batch_size, d0, .. dN]`.",
-                                ":cvar return_type: Squared hinge loss values. shape = `[batch_size, d0, .. dN-1]`."
-                                " Defaults to ```K.mean(math_ops.square(math_ops.maximum(1.0 - y_true * y_pred, 0.0)),"
-                                " axis=-1)```",
+                                ":cvar return_type: Squared hinge loss values. shape = `[batch_size, d0, .. dN-1]`.",
                             ),
                         )
                     ),
@@ -764,7 +715,6 @@ class TensorBoard(Callback, version_utils.TensorBoardVersionSelector):
                histogram_freq=0,
                write_graph=True,
                write_images=False,
-               write_steps_per_second=False,
                update_freq='epoch',
                profile_batch=2,
                embeddings_freq=0,
@@ -801,7 +751,6 @@ class_google_tf_tensorboard_ast = ClassDef(
                             "histogram_freq",
                             "write_graph",
                             "write_images",
-                            "write_steps_per_second",
                             "update_freq",
                             "profile_batch",
                             "embeddings_freq",
@@ -813,7 +762,7 @@ class_google_tf_tensorboard_ast = ClassDef(
                 kw_defaults=[],
                 kwarg=set_arg("kwargs"),
                 defaults=list(
-                    map(set_value, ("logs", 0, True, False, False, "epoch", 2, 0, None))
+                    map(set_value, ("logs", 0, True, False, "epoch", 2, 0, None))
                 ),
                 vararg=None,
             ),
