@@ -3,12 +3,12 @@
 from ast import ClassDef
 from functools import partial
 from io import StringIO
-from itertools import groupby
+from itertools import chain, groupby
 from operator import add, itemgetter
 from os import environ, mkdir, path
 from os.path import extsep
 from subprocess import DEVNULL, call
-from sys import executable
+from sys import executable, platform
 from tempfile import TemporaryDirectory
 from unittest import TestCase
 from unittest.mock import patch
@@ -16,7 +16,7 @@ from unittest.mock import patch
 from cdd import parse
 from cdd.exmod import exmod
 from cdd.pkg_utils import relative_filename
-from cdd.pure_utils import ENCODING, rpartial, unquote
+from cdd.pure_utils import ENCODING, INIT_FILENAME, rpartial, unquote
 from cdd.source_transformer import ast_parse
 from cdd.tests.mocks import imports_header
 from cdd.tests.mocks.classes import class_str
@@ -59,17 +59,17 @@ class TestExMod(TestCase):
         with TemporaryDirectory() as tempdir, self.assertRaises(NotImplementedError):
             exmod(
                 module=tempdir,
-                emit_name=None,
+                emit_name="cjvxclkvjclxkjvlcx",
                 blacklist=["foo", "bar"],
                 whitelist=tuple(),
-                output_directory=tempdir,
+                output_directory=path.join(tempdir, "nonexistent"),
                 dry_run=False,
             )
 
     def test_exmod_output_directory_nonexistent(self) -> None:
         """Tests `exmod` module whence directory does not exist"""
 
-        with TemporaryDirectory() as tempdir, self.assertRaises(AssertionError):
+        with TemporaryDirectory() as tempdir, self.assertRaises(ModuleNotFoundError):
             output_directory = path.join(tempdir, "stuff")
             self.assertFalse(path.isdir(output_directory))
             exmod(
@@ -115,9 +115,7 @@ class TestExMod(TestCase):
         open(path.join(tempdir, "README{extsep}md".format(extsep=extsep)), "a").close()
         mkdir(path.join(tempdir, self.module_name))
         with open(
-            path.join(
-                tempdir, self.module_name, "__init__{extsep}py".format(extsep=extsep)
-            ),
+            path.join(tempdir, self.module_name, INIT_FILENAME),
             "wt",
         ) as f:
             f.write(
@@ -316,56 +314,173 @@ class TestExMod(TestCase):
                         dry_run=True,
                     )
                     r = f.getvalue()
+
                 result = dict(
                     map(
                         lambda k_v: (
                             k_v[0],
                             tuple(
-                                map(
-                                    partial(
-                                        relative_filename,
-                                        remove_hints=(
-                                            path.join(
-                                                new_module_dir,
-                                                path.basename(new_module_dir),
+                                sorted(
+                                    set(
+                                        map(
+                                            partial(
+                                                relative_filename,
+                                                remove_hints=(
+                                                    (
+                                                        lambda directory: "{directory}{sep}".format(
+                                                            directory=unquote(
+                                                                repr(directory)
+                                                            ),
+                                                            sep=path.sep,
+                                                        )
+                                                        if platform == "win32"
+                                                        else directory
+                                                    )(
+                                                        path.join(
+                                                            new_module_dir,
+                                                            path.basename(
+                                                                new_module_dir
+                                                            ),
+                                                        ),
+                                                    ),
+                                                ),
                                             ),
-                                        ),
-                                    ),
-                                    map(unquote, sorted(map(itemgetter(1), k_v[1]))),
+                                            map(unquote, map(itemgetter(1), k_v[1])),
+                                        )
+                                    )
                                 )
                             ),
                         ),
                         groupby(
-                            map(rpartial(str.split, "\t"), r.splitlines()),
+                            map(rpartial(str.split, "\t", 2), sorted(r.splitlines())),
                             key=itemgetter(0),
                         ),
                     )
                 )
-                for key, count in ("mkdir", 1), ("touch", 1), ("write", 3):
-                    self.assertEqual(len(result[key]), count)
 
-                self.assertDictEqual(
-                    result,
-                    {
-                        "mkdir": (
-                            path.join(
-                                self.module_hierarchy[0][1], self.module_hierarchy[0][0]
-                            ),
+                all_tests_running = len(result["write"]) == 7
+
+                key_counts = (
+                    (("mkdir", 10), ("touch", 4), ("write", 7))
+                    if all_tests_running
+                    else (("mkdir", 7), ("touch", 4), ("write", 4))
+                )
+
+                for key, count in key_counts:
+                    self.assertEqual(count, len(result[key]), key)
+
+                gold_module_name = next(
+                    map(
+                        lambda p: p.partition(path.sep)[0],
+                        filter(rpartial(str.startswith, "gold"), result["write"]),
+                    ),
+                    "",
+                )
+                gold = {
+                    k: tuple(map(unquote, map(repr, v)))
+                    for k, v in {
+                        "mkdir": chain.from_iterable(
+                            (
+                                (new_module_dir,),
+                                (
+                                    path.join(
+                                        gold_module_name, self.module_hierarchy[0][1]
+                                    ),
+                                    path.join(
+                                        gold_module_name, self.module_hierarchy[1][1]
+                                    ),
+                                    path.join(
+                                        gold_module_name, self.module_hierarchy[2][1]
+                                    ),
+                                )
+                                if all_tests_running
+                                else iter(()),
+                                (
+                                    self.module_hierarchy[0][1],
+                                    self.module_hierarchy[1][1],
+                                    path.join(
+                                        self.module_hierarchy[1][1],
+                                        self.module_hierarchy[1][0],
+                                    ),
+                                    self.module_hierarchy[2][1],
+                                    path.join(
+                                        self.module_hierarchy[2][1],
+                                        self.module_hierarchy[2][0],
+                                    ),
+                                    path.join(
+                                        self.module_hierarchy[0][1],
+                                        self.module_hierarchy[0][0],
+                                    ),
+                                ),
+                            )
                         ),
                         "touch": (
-                            path.join(self.module_hierarchy[0][1], "__init__.py"),
+                            INIT_FILENAME,
+                            path.join(
+                                self.module_hierarchy[0][1],
+                                INIT_FILENAME,
+                            ),
+                            path.join(
+                                self.module_hierarchy[1][1],
+                                INIT_FILENAME,
+                            ),
+                            path.join(
+                                self.module_hierarchy[2][1],
+                                INIT_FILENAME,
+                            ),
                         ),
                         "write": (
-                            "__init__.py",
-                            path.join(self.module_hierarchy[0][1], "parent.py"),
-                            path.join(self.module_hierarchy[0][1], "parent.py"),
+                            lambda write_block: tuple(
+                                sorted(
+                                    chain.from_iterable(
+                                        (
+                                            map(
+                                                partial(path.join, gold_module_name),
+                                                write_block[1:],
+                                            ),
+                                            write_block,
+                                        )
+                                    )
+                                )
+                            )
+                            if all_tests_running
+                            else write_block
+                        )(
+                            (
+                                INIT_FILENAME,
+                                path.join(
+                                    self.module_hierarchy[1][1],
+                                    "{name}{extsep}py".format(
+                                        name=self.module_hierarchy[1][0],
+                                        extsep=extsep,
+                                    ),
+                                ),
+                                path.join(
+                                    self.module_hierarchy[2][1],
+                                    "{name}{extsep}py".format(
+                                        name=self.module_hierarchy[2][0],
+                                        extsep=extsep,
+                                    ),
+                                ),
+                                path.join(
+                                    self.module_hierarchy[0][1],
+                                    "{name}{extsep}py".format(
+                                        name=self.module_hierarchy[0][0],
+                                        extsep=extsep,
+                                    ),
+                                ),
+                            )
                         ),
-                    },
-                )
+                    }.items()
+                }
+
+                self.assertDictEqual(result, gold)
 
                 self.check_emission(new_module_dir, dry_run=True)
         finally:
             self._pip(["uninstall", "-y", self.module_name])
 
+    maxDiff = None
+
 
 unittest_main()
